@@ -2,7 +2,7 @@
 
 import sys
 import argparse
-import Intercaat.intercaat_functions as icaat
+import intercaat_functions as icaat
 
 def main():
     descr = '''
@@ -68,7 +68,7 @@ def main():
         pdb = icaat.parse(PDBFileName, (arg2 + arg3 + arg8), arg9)
     except FileNotFoundError:
         sys.exit(f'{PDBFileName} was not found')
-    print(PDBFileName,arg2, arg3 )
+    print(PDBFileName,str(arg2), str(arg3) )
     coordinates = []
     match = []
 
@@ -77,8 +77,8 @@ def main():
         coordinates.append([line[8], line[9], line[10]])
 
     # Creates 3D voronoi diagram and returns indices of neighboring atoms
-    # contacts = icaat.run_voro(coordinates)
-    contacts =  icaat.voroPyhull(coordinates)
+    contacts = icaat.run_voro(coordinates)
+    # contacts =  icaat.voroPyhull(coordinates)
     # Creates a list (pdbAtomClass) that contains classes for all atoms analayzed 
     pdbAtomClass = icaat.appendAtomClasses(pdb)
 
